[![pypi](https://img.shields.io/pypi/v/lnschema_core?color=%2334D058&label=pypi%20package)](https://pypi.org/project/lnschema_core)

# lnschema-core: Data provenance & flow (`yvzi`)

Read the [docs](https://lamin.ai/docs/lnschema-core).
